@@ -3,7 +3,9 @@ package org.gcube.social_networking.socialutillibrary;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -39,21 +41,27 @@ public class Utils {
 	/**
 	 * Hashtag regex enhanced for ticket #4937
 	 */
+
 	private static final String HASHTAG_REGEX = "^#\\w+([-_.]?\\w+)*|\\s#\\w+([-_.]?\\w+)*|(?<=[\\[({])#\\w+([-_.]?\\w+)";
+	
+	private static final String MENTIONS_REGEX = "^@\\w+([-_.]?\\w+)*|\\s@\\w+([-_.]?\\w+)*|(?<=[\\[({])@\\w+([-_.]?\\w+)";
 
 	/**
 	 * IPv4 regex
 	 */
+
 	public static final String IPV4_REGEX = "\\b(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\b";
 
 	/**
 	 * IPV6 regex needs to be put in square brackets, see below
 	 */
+
 	public static final String IPV6_REGEX = "\\b(?:[0-9a-fA-F]{1,4}:){7}[0-9a-fA-F]{1,4}\\b";
 
 	/**
 	 * Pattern for URLS
 	 */
+
 	private static final Pattern URL_PATTERN = Pattern.compile(
 			"\\b(((ht|f)tp(s?)\\:\\/\\/|~\\/|\\/)|www.)" + 
 					"(\\w+:\\w+@)?((([-\\w]+\\.)+(com|org|net|gov" + 
@@ -76,10 +84,26 @@ public class Utils {
 		sb.append("<span style=\"color:gray; font-size:12px;\">shared </span><a class=\"link\" href=\"").append(url).append("\" target=\"_blank\">").append("a file.").append("</a> ").toString();
 		return sb.toString();
 	}
+	/**
+	 * 
+	 * @param postText
+	 * @return a set containing the list of mentions found
+	 */
+	public static Set<String> getMentionedUsernames(String postText) {
+		Set<String> mentions = new HashSet<>();		
+		Pattern MY_PATTERN = Pattern.compile(MENTIONS_REGEX);
+		Matcher matcher = MY_PATTERN.matcher(postText);
+		while (matcher.find()) {
+			mentions.add(matcher.group().replace("@", "").trim());
+		}
+		return mentions;		
+	}
+	
+	
 
 	/**
 	 * 
-	 * @param session the Asl Session
+	 * @param scope the context
 	 * @param withinPortal true when is on Liferay portal
 	 * @return the users plus the groups belonging to the current organization (scope) 
 	 */
@@ -157,12 +181,14 @@ public class Utils {
 	 * @param postText
 	 * @return the list of hashtags present in the text
 	 */
+
 	public static List<String> getHashTags(String postText) {
 		List<String> hashtags = new ArrayList<>();		
 		Pattern MY_PATTERN = Pattern.compile(HASHTAG_REGEX);//Pattern.compile("^#\\w+|\\s#\\w+");
 		Matcher matcher = MY_PATTERN.matcher(postText);
 		while (matcher.find()) {
-			hashtags.add("#"+matcher.group().replace(" ", "").replace("#", ""));
+			System.out.println("matcher.find()='"+matcher.group()+"'");
+			hashtags.add("#"+matcher.group().replace(" ", "").replace("\n", "").replace("#", ""));
 		}
 		return hashtags;		
 	}
@@ -173,6 +199,7 @@ public class Utils {
 	 * @param feedText
 	 * @return the text with the clickable url in it
 	 */
+
 	public static String extractURL(String feedText) {
 		// separate input by spaces ( URLs have no spaces )
 		feedText = feedText.replaceAll("(\r\n|\n)"," <br/> ");
@@ -201,6 +228,7 @@ public class Utils {
 	 * @param html the html string to escape
 	 * @return the escaped string
 	 */
+
 	public static String escapeHtmlAndTransformUrl(String html) {
 		if (html == null) {
 			return null;
@@ -223,6 +251,7 @@ public class Utils {
 	 * @param html the html string to escape
 	 * @return the escaped string
 	 */
+
 	public static String escapeHtml(String html) {
 		return html.replaceAll("&", "&amp;").replaceAll("<", "&lt;")
 				.replaceAll(">", "&gt;");
@@ -234,6 +263,7 @@ public class Utils {
 	 * @param feedText
 	 * @return the text with the clickable url in it
 	 */
+
 	public static String transformUrls(String feedText) {
 		StringBuilder sb = new StringBuilder();
 		// separate input by spaces ( URLs have no spaces )
@@ -267,6 +297,7 @@ public class Utils {
 	 * @param item a text token
 	 * @return the actual http link
 	 */
+
 	public static String getHttpToken(String originalItem) {
 		// apply pattern
 		String item = null;
@@ -288,20 +319,26 @@ public class Utils {
 		return item;
 	}
 
+	
 	/**
 	 * convert the mentioned people in HTML anchor and also Encode the params Base64
 	 * @param escapedFeedText
 	 * @param taggedPeople
 	 * @return
 	 */
+
 	public static String convertMentionPeopleAnchorHTML(String escapedFeedText, ArrayList<ItemBean> taggedPeople, HttpServletRequest request) {
 		String pageToRedirectURL = "";
 		String httpGETAttrName = "";
 		String httpGETAttrValue ="";
-
+		PortalContext pContext = PortalContext.getConfiguration();
+		String gatewayURL = pContext.getGatewayURL(request);
 		for (ItemBean tagged : taggedPeople) {
 			if (! tagged.isItemGroup()) {
-				pageToRedirectURL = PortalContext.getConfiguration().getSiteLandingPagePath(request)+GCubePortalConstants.USER_PROFILE_FRIENDLY_URL;
+				StringBuilder sb = new StringBuilder(gatewayURL)
+				.append(pContext.getSiteLandingPagePath(request))
+				.append(GCubePortalConstants.USER_PROFILE_FRIENDLY_URL);
+				pageToRedirectURL = sb.toString();
 				httpGETAttrName = GCubeSocialNetworking.USER_PROFILE_OID;
 				httpGETAttrValue = tagged.getName();
 			} else {
@@ -311,7 +348,11 @@ public class Utils {
 					//returns the VRE url e.g. /devVRE
 					String vreURL  = new LiferayGroupManager().getGroup(theTeam.getGroupId()).getFriendlyURL();
 					//append the members url
-					pageToRedirectURL= GCubePortalConstants.PREFIX_GROUP_URL + vreURL + GCubePortalConstants.GROUP_MEMBERS_FRIENDLY_URL;
+					StringBuilder sb = new StringBuilder(gatewayURL)
+							.append(GCubePortalConstants.PREFIX_GROUP_URL)
+							.append(vreURL)
+							.append(GCubePortalConstants.GROUP_MEMBERS_FRIENDLY_URL);
+					pageToRedirectURL= sb.toString();
 					httpGETAttrName = GCubeSocialNetworking.GROUP_MEMBERS_OID;		
 					httpGETAttrValue = tagged.getId();
 				} catch (Exception e) {
@@ -327,12 +368,42 @@ public class Utils {
 		return escapedFeedText;
 	}
 
+	/**
+	 * convert the mentioned people in HTML anchor and also Encode the params Base64
+	 * @param escapedFeedText
+	 * @param taggedPeople
+	 * @return
+	 */
+
+	public static String convertMentionUsernamesAnchorHTML(String escapedPostText, ArrayList<ItemBean> mentionedUsers, String gatewayURL, String landingPagePath) {
+		String pageToRedirectURL = "profile";
+		String httpGETAttrName = "";
+		String httpGETAttrValue ="";
+				
+		for (ItemBean tagged : mentionedUsers) {
+			StringBuilder sb = new StringBuilder(gatewayURL)
+					.append(landingPagePath)
+					.append(GCubePortalConstants.USER_PROFILE_FRIENDLY_URL);
+					pageToRedirectURL = sb.toString();
+					httpGETAttrName = GCubeSocialNetworking.USER_PROFILE_OID;
+					httpGETAttrValue = tagged.getName();
+			String taggedHTML = "<a class=\"link\" href=\""+pageToRedirectURL
+					+"?"+
+					new String(Base64.encodeBase64(httpGETAttrName.getBytes()))+"="+
+					new String(Base64.encodeBase64(httpGETAttrValue.getBytes()))+"\">"+tagged.getAlternativeName()+"</a> ";
+			escapedPostText = escapedPostText.replace("@"+tagged.getName(), taggedHTML);
+		}
+		return escapedPostText;
+	}
+	
+	
 	/**
 	 * convert the hashtag in HTML anchor and also Encode the params Base64
 	 * @param escapedFeedText
 	 * @param hashtags
 	 * @return
 	 */
+
 	public static String convertHashtagsAnchorHTML(String escapedFeedText, List<String> hashtags) {
 		for (String hashtag : hashtags) {
 			String taggedHTML = "<a class=\"link\" style=\"font-size:14px;\" href=\"?"+
@@ -368,6 +439,7 @@ public class Utils {
 	 * @param text
 	 * @return a String without html tags
 	 */
+
 	public static String removeHTMLFromText(String text){
 
 		if(text == null)
